searchData={"items":[{"type":"module","title":"TwiML","doc":"Generate complex TwiML documents for Twilio in an elegant Elixir way.\n\n> ##","ref":"TwiML.html"},{"type":"module","title":"Note {: .warning} - TwiML","doc":">\n> Please refer to the [official TwiML\n> documentation](https://www.twilio.com/docs/voice/twiml) to verify that the\n> TwiML verb actually supports content or the given attributes.","ref":"TwiML.html#module-note-warning"},{"type":"module","title":"Examples - TwiML","doc":"Say something:\n\n```elixir\niex> TwiML.say(\"Hello\") |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   Hello \n \\\n\"\"\"\n```\n\nSay 2 things, one after the other:\n\n```elixir\niex> TwiML.say(\"Hello\") |> TwiML.say(\"world\") |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   Hello \n   world \n \\\n\"\"\"\n```\n\nSay something in another voice:\n\n```elixir\niex> TwiML.say(\"Hello\", voice: \"woman\") |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   Hello \n \\\n\"\"\"\n```\n\nLeaving the content empty for a TwiML verb, will create a TwiML element that has\nno body:\n\n```elixir\niex> TwiML.hangup() |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   \n \\\n\"\"\"\n```\n\nYou can embed TwiML tags into other tags using the `into_*` function:\n\n```elixir\niex> TwiML.say(\"Lets say this inside the gather\")\n...> |> TwiML.into_gather(language: \"en-US\", input: \"speech\")\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   \n     Lets say this inside the gather \n   \n \\\n\"\"\"\n```\n\nIf you have multiple TwiML tags you want to embed, that works too:\n\n```elixir\niex> TwiML.say(\"Hi\")\n...> |> TwiML.say(\"We cool?\")\n...> |> TwiML.into_gather(language: \"en-US\", input: \"speech\", hints: \"yes, no\")\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   \n     Hi \n     We cool? \n   \n \\\n\"\"\"\n```\n\nIt is also possible to just include a few of the preceding tags into the body of\nanother element. The `1` decides that we want to only put the last element into\nthe Dial element's body:\n\n```elixir\niex> TwiML.say(\"Calling Yodel\")\n...> |> TwiML.number(\"+1 415-483-0400\")\n...> |> TwiML.into_dial(1)\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   Calling Yodel \n   \n     +1 415-483-0400 \n   \n \\\n\"\"\"\n```\n\nThe `into_*` functions can take the number of preceding tags, attributes or both\nas arguments:\n\n```elixir\niex> TwiML.identity(\"venkman\")\n...> |> TwiML.into_client(1)\n...> |> TwiML.identity(\"stantz\")\n...> |> TwiML.into_client(1, method: \"GET\")\n...> |> TwiML.into_dial(caller: \"+1 415-483-0400\")\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   \n     \n       venkman \n     \n     \n       stantz \n     \n   \n \\\n\"\"\"\n```\n\nMultiple calls to `into_*` functions allow building complex nested TwiML\nstructures without losing readability in the code due to nested function calls:\n\n```elixir\niex> TwiML.identity(\"venkman\")\n...> |> TwiML.parameter(name: \"first_name\", value: \"Peter\")\n...> |> TwiML.parameter(name: \"last_name\", value: \"Venkman\")\n...> |> TwiML.into_client(3)\n...> |> TwiML.into_dial(1)\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   \n     \n       venkman \n       \n       \n     \n   \n \\\n\"\"\"\n```\n\nAttributes can be provided both as `snake_case` or `camelCase`, but the latter is preferred as the code looks more Elixir-like.\n\n```elixir\niex> TwiML.dial(\"+1 415-483-0400\", recordingStatusCallback: \"https://example.org\", recording_status_callback_method: \"POST\")\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   +1 415-483-0400 \n \\\n\"\"\"\n```\n\nSafe binary strings, **IO Data** or **CDATA** are supported as well. Make sure\nto only mark actually safe data as safe!\n\n```elixir\niex> TwiML.say({:safe, \" Hello World \"})\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n    Hello World  \n \\\n\"\"\"\n\niex> TwiML.say({:iodata, [104, 101, 108, 108, 111, 32, 119, 111, 114, 108, 100]})\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   hello world \n \\\n\"\"\"\n\niex> TwiML.say({:cdata, \" \\\\ \"})\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   <![CDATA[ \\\\ ]]> \n \\\n\"\"\"\n```\n\nThis also works with attributes:\n\n```elixir\niex> TwiML.say({:safe, \" Hello World \"}, voice: \"Polly.Joanna\")\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\\\"?>\n \n    Hello World  \n \\\n\"\"\"\n\niex> TwiML.say({:iodata, [104, 101, 108, 108, 111, 32, 119, 111, 114, 108, 100]}, voice: \"Polly.Joanna\")\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   hello world \n \\\n\"\"\"\n\niex> TwiML.say({:cdata, \" \\\\ \"}, voice: \"Polly.Joanna\")\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   <![CDATA[ \\\\ ]]> \n \\\n\"\"\"\n```\n\nComments can help with debugging (yes, they are somewhat ugly, until `xml_builder` properly supports them):\n\n```elixir\niex> TwiML.comment(\"Blocked because of insufficient funds\")\n...> |> TwiML.reject()\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n  <!-->Blocked because of insufficient funds</!-->\n   \n \\\n\"\"\"\n```\n\nAnd can also be chained:\n\n```elixir\niex> TwiML.say(\"Sorry, calls are currently unavailable\")\n...> |> TwiML.comment(\"Blocked because of insufficient funds\")\n...> |> TwiML.reject()\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   Sorry, calls are currently unavailable \n  <!-->Blocked because of insufficient funds</!-->\n   \n \\\n\"\"\"\n```\n\nEmpty attributes are not included in the generated TwiML:\n\n```elixir\niex> TwiML.say(\"Hello\", voice: \"\", loop: nil)\n...> |> TwiML.to_xml()\n\"\"\"\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   Hello \n \\\n\"\"\"\n```","ref":"TwiML.html#module-examples"},{"type":"function","title":"TwiML.application/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#application/0"},{"type":"function","title":"TwiML.application/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#application/1"},{"type":"function","title":"TwiML.application/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#application/2"},{"type":"function","title":"TwiML.application/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#application/3"},{"type":"function","title":"TwiML.autopilot/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#autopilot/0"},{"type":"function","title":"TwiML.autopilot/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#autopilot/1"},{"type":"function","title":"TwiML.autopilot/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#autopilot/2"},{"type":"function","title":"TwiML.autopilot/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#autopilot/3"},{"type":"function","title":"TwiML.client/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#client/0"},{"type":"function","title":"TwiML.client/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#client/1"},{"type":"function","title":"TwiML.client/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#client/2"},{"type":"function","title":"TwiML.client/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#client/3"},{"type":"function","title":"TwiML.comment/1","doc":"Generates a comment.","ref":"TwiML.html#comment/1"},{"type":"function","title":"Examples - TwiML.comment/1","doc":"iex> TwiML.comment(\"Blocked because of insufficient funds\")\n    ...> |> TwiML.to_xml(format: :none)\n    ~s(<?xml version=\"1.0\" encoding=\"UTF-8\"?> <!-->Blocked because of insufficient funds</!--> )","ref":"TwiML.html#comment/1-examples"},{"type":"function","title":"TwiML.comment/2","doc":"Appends a comment to the TwiML.","ref":"TwiML.html#comment/2"},{"type":"function","title":"Examples - TwiML.comment/2","doc":"iex> TwiML.reject() |> TwiML.comment(\"Blocked because of insufficient funds\") |> TwiML.to_xml(format: :none)\n    ~s(<?xml version=\"1.0\" encoding=\"UTF-8\"?>  <!-->Blocked because of insufficient funds</!--> )","ref":"TwiML.html#comment/2-examples"},{"type":"function","title":"TwiML.conference/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#conference/0"},{"type":"function","title":"TwiML.conference/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#conference/1"},{"type":"function","title":"TwiML.conference/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#conference/2"},{"type":"function","title":"TwiML.conference/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#conference/3"},{"type":"function","title":"TwiML.connect/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#connect/0"},{"type":"function","title":"TwiML.connect/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#connect/1"},{"type":"function","title":"TwiML.connect/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#connect/2"},{"type":"function","title":"TwiML.connect/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#connect/3"},{"type":"function","title":"TwiML.dial/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#dial/0"},{"type":"function","title":"TwiML.dial/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#dial/1"},{"type":"function","title":"TwiML.dial/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#dial/2"},{"type":"function","title":"TwiML.dial/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#dial/3"},{"type":"function","title":"TwiML.enqueue/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#enqueue/0"},{"type":"function","title":"TwiML.enqueue/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#enqueue/1"},{"type":"function","title":"TwiML.enqueue/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#enqueue/2"},{"type":"function","title":"TwiML.enqueue/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#enqueue/3"},{"type":"function","title":"TwiML.gather/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#gather/0"},{"type":"function","title":"TwiML.gather/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#gather/1"},{"type":"function","title":"TwiML.gather/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#gather/2"},{"type":"function","title":"TwiML.gather/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#gather/3"},{"type":"function","title":"TwiML.hangup/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#hangup/0"},{"type":"function","title":"TwiML.hangup/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#hangup/1"},{"type":"function","title":"TwiML.hangup/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#hangup/2"},{"type":"function","title":"TwiML.hangup/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#hangup/3"},{"type":"function","title":"TwiML.identity/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#identity/0"},{"type":"function","title":"TwiML.identity/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#identity/1"},{"type":"function","title":"TwiML.identity/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#identity/2"},{"type":"function","title":"TwiML.identity/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#identity/3"},{"type":"function","title":"TwiML.into_application/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_application/2"},{"type":"function","title":"TwiML.into_application/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_application/3"},{"type":"function","title":"TwiML.into_autopilot/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_autopilot/2"},{"type":"function","title":"TwiML.into_autopilot/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_autopilot/3"},{"type":"function","title":"TwiML.into_client/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_client/2"},{"type":"function","title":"TwiML.into_client/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_client/3"},{"type":"function","title":"TwiML.into_conference/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_conference/2"},{"type":"function","title":"TwiML.into_conference/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_conference/3"},{"type":"function","title":"TwiML.into_connect/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_connect/2"},{"type":"function","title":"TwiML.into_connect/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_connect/3"},{"type":"function","title":"TwiML.into_dial/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_dial/2"},{"type":"function","title":"TwiML.into_dial/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_dial/3"},{"type":"function","title":"TwiML.into_enqueue/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_enqueue/2"},{"type":"function","title":"TwiML.into_enqueue/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_enqueue/3"},{"type":"function","title":"TwiML.into_gather/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_gather/2"},{"type":"function","title":"TwiML.into_gather/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_gather/3"},{"type":"function","title":"TwiML.into_hangup/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_hangup/2"},{"type":"function","title":"TwiML.into_hangup/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_hangup/3"},{"type":"function","title":"TwiML.into_identity/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_identity/2"},{"type":"function","title":"TwiML.into_identity/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_identity/3"},{"type":"function","title":"TwiML.into_leave/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_leave/2"},{"type":"function","title":"TwiML.into_leave/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_leave/3"},{"type":"function","title":"TwiML.into_number/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_number/2"},{"type":"function","title":"TwiML.into_number/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_number/3"},{"type":"function","title":"TwiML.into_parameter/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_parameter/2"},{"type":"function","title":"TwiML.into_parameter/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_parameter/3"},{"type":"function","title":"TwiML.into_pause/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_pause/2"},{"type":"function","title":"TwiML.into_pause/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_pause/3"},{"type":"function","title":"TwiML.into_pay/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_pay/2"},{"type":"function","title":"TwiML.into_pay/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_pay/3"},{"type":"function","title":"TwiML.into_play/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_play/2"},{"type":"function","title":"TwiML.into_play/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_play/3"},{"type":"function","title":"TwiML.into_prompt/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_prompt/2"},{"type":"function","title":"TwiML.into_prompt/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_prompt/3"},{"type":"function","title":"TwiML.into_queue/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_queue/2"},{"type":"function","title":"TwiML.into_queue/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_queue/3"},{"type":"function","title":"TwiML.into_record/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_record/2"},{"type":"function","title":"TwiML.into_record/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_record/3"},{"type":"function","title":"TwiML.into_redirect/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_redirect/2"},{"type":"function","title":"TwiML.into_redirect/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_redirect/3"},{"type":"function","title":"TwiML.into_refer/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_refer/2"},{"type":"function","title":"TwiML.into_refer/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_refer/3"},{"type":"function","title":"TwiML.into_reject/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_reject/2"},{"type":"function","title":"TwiML.into_reject/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_reject/3"},{"type":"function","title":"TwiML.into_say/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_say/2"},{"type":"function","title":"TwiML.into_say/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_say/3"},{"type":"function","title":"TwiML.into_sim/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_sim/2"},{"type":"function","title":"TwiML.into_sim/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_sim/3"},{"type":"function","title":"TwiML.into_sip/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_sip/2"},{"type":"function","title":"TwiML.into_sip/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_sip/3"},{"type":"function","title":"TwiML.into_siprec/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_siprec/2"},{"type":"function","title":"TwiML.into_siprec/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_siprec/3"},{"type":"function","title":"TwiML.into_stream/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_stream/2"},{"type":"function","title":"TwiML.into_stream/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_stream/3"},{"type":"function","title":"TwiML.into_virtual_agent/2","doc":"Wraps preceding TwiML verbs in a ` ` verb.\n\nThere are three supported usages:\n- Uses `attrs_or_last_n_elements` as attributes to wrap all preceding verbs\n  in ` ` if it's a keyword list.\n- Wraps all preceding verbs in ` ` if `attrs_or_last_n_elements` is\n  `:all`.\n- Encloses the last `attrs_or_last_n_elements` verbs in ` ` if it's a\n  positive integer.","ref":"TwiML.html#into_virtual_agent/2"},{"type":"function","title":"TwiML.into_virtual_agent/3","doc":"Wraps preceding TwiML verbs in a ` ` verb with attributes.\n\nThere are three supported usages:\n- Wraps all preceding verbs in ` ` using `attrs` as attributes if\n  `last_n_elements` is `:all`.\n- Encloses the last `last_n_elements` verbs in ` ` using `attrs`\n  as attribute if it's a positive integer.","ref":"TwiML.html#into_virtual_agent/3"},{"type":"function","title":"TwiML.leave/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#leave/0"},{"type":"function","title":"TwiML.leave/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#leave/1"},{"type":"function","title":"TwiML.leave/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#leave/2"},{"type":"function","title":"TwiML.leave/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#leave/3"},{"type":"function","title":"TwiML.number/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#number/0"},{"type":"function","title":"TwiML.number/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#number/1"},{"type":"function","title":"TwiML.number/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#number/2"},{"type":"function","title":"TwiML.number/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#number/3"},{"type":"function","title":"TwiML.parameter/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#parameter/0"},{"type":"function","title":"TwiML.parameter/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#parameter/1"},{"type":"function","title":"TwiML.parameter/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#parameter/2"},{"type":"function","title":"TwiML.parameter/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#parameter/3"},{"type":"function","title":"TwiML.pause/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#pause/0"},{"type":"function","title":"TwiML.pause/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#pause/1"},{"type":"function","title":"TwiML.pause/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#pause/2"},{"type":"function","title":"TwiML.pause/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#pause/3"},{"type":"function","title":"TwiML.pay/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#pay/0"},{"type":"function","title":"TwiML.pay/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#pay/1"},{"type":"function","title":"TwiML.pay/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#pay/2"},{"type":"function","title":"TwiML.pay/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#pay/3"},{"type":"function","title":"TwiML.play/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#play/0"},{"type":"function","title":"TwiML.play/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#play/1"},{"type":"function","title":"TwiML.play/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#play/2"},{"type":"function","title":"TwiML.play/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#play/3"},{"type":"function","title":"TwiML.prompt/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#prompt/0"},{"type":"function","title":"TwiML.prompt/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#prompt/1"},{"type":"function","title":"TwiML.prompt/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#prompt/2"},{"type":"function","title":"TwiML.prompt/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#prompt/3"},{"type":"function","title":"TwiML.queue/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#queue/0"},{"type":"function","title":"TwiML.queue/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#queue/1"},{"type":"function","title":"TwiML.queue/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#queue/2"},{"type":"function","title":"TwiML.queue/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#queue/3"},{"type":"function","title":"TwiML.record/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#record/0"},{"type":"function","title":"TwiML.record/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#record/1"},{"type":"function","title":"TwiML.record/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#record/2"},{"type":"function","title":"TwiML.record/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#record/3"},{"type":"function","title":"TwiML.redirect/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#redirect/0"},{"type":"function","title":"TwiML.redirect/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#redirect/1"},{"type":"function","title":"TwiML.redirect/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#redirect/2"},{"type":"function","title":"TwiML.redirect/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#redirect/3"},{"type":"function","title":"TwiML.refer/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#refer/0"},{"type":"function","title":"TwiML.refer/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#refer/1"},{"type":"function","title":"TwiML.refer/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#refer/2"},{"type":"function","title":"TwiML.refer/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#refer/3"},{"type":"function","title":"TwiML.reject/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#reject/0"},{"type":"function","title":"TwiML.reject/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#reject/1"},{"type":"function","title":"TwiML.reject/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#reject/2"},{"type":"function","title":"TwiML.reject/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#reject/3"},{"type":"function","title":"TwiML.say/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#say/0"},{"type":"function","title":"TwiML.say/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#say/1"},{"type":"function","title":"TwiML.say/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#say/2"},{"type":"function","title":"TwiML.say/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#say/3"},{"type":"function","title":"TwiML.sim/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#sim/0"},{"type":"function","title":"TwiML.sim/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#sim/1"},{"type":"function","title":"TwiML.sim/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#sim/2"},{"type":"function","title":"TwiML.sim/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#sim/3"},{"type":"function","title":"TwiML.sip/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#sip/0"},{"type":"function","title":"TwiML.sip/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#sip/1"},{"type":"function","title":"TwiML.sip/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#sip/2"},{"type":"function","title":"TwiML.sip/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#sip/3"},{"type":"function","title":"TwiML.siprec/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#siprec/0"},{"type":"function","title":"TwiML.siprec/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#siprec/1"},{"type":"function","title":"TwiML.siprec/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#siprec/2"},{"type":"function","title":"TwiML.siprec/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#siprec/3"},{"type":"function","title":"TwiML.stream/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#stream/0"},{"type":"function","title":"TwiML.stream/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#stream/1"},{"type":"function","title":"TwiML.stream/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#stream/2"},{"type":"function","title":"TwiML.stream/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#stream/3"},{"type":"function","title":"TwiML.to_xml/2","doc":"Generates a XML document from the provided verbs and arguments. For the\nsupported `opts`, please refer to the documentation of\n`XmlBuilder.generate/2`.","ref":"TwiML.html#to_xml/2"},{"type":"function","title":"Examples - TwiML.to_xml/2","doc":"iex> TwiML.say(\"Hello world\")\n    ...> |> TwiML.to_xml(format: :none)\n    ~s(<?xml version=\"1.0\" encoding=\"UTF-8\"?>  Hello world  )","ref":"TwiML.html#to_xml/2-examples"},{"type":"function","title":"TwiML.virtual_agent/0","doc":"Generates an empty ` ` verb.","ref":"TwiML.html#virtual_agent/0"},{"type":"function","title":"TwiML.virtual_agent/1","doc":"Generates a ` ` verb.\n\nThere are three supported usages:\n\n- Wraps `arg` in ` ` if it's `t:TwiML.content/0`.\n- Creates an empty ` ` with attributes for `arg` as a keyword\n  list.\n- Appends an empty ` ` to `arg` if it's `t:TwiML.t/0`, enabling\n  verb chaining (refer to [Examples](#module-examples)).","ref":"TwiML.html#virtual_agent/1"},{"type":"function","title":"TwiML.virtual_agent/2","doc":"Appends or generates a ` ` verb.\n\nThere are two supported usages:\n\n- Appends ` ` to `verbs_or_content` if it's `t:TwiML.t/0`,\n  enabling verb chaining (see [Examples](#module-examples)). This verb\n  wraps `content_or_attrs` if it's `t:TwiML.content/0`, or includes\n  attributes if `content_or_attrs` is a keyword list.\n- Generates ` ` with attributes if `content_or_attrs` is a\n  keyword list.","ref":"TwiML.html#virtual_agent/2"},{"type":"function","title":"TwiML.virtual_agent/3","doc":"Appends a ` ` verb with attributes.\n\nAdds a ` ` verb to `verbs` using `attrs` as attributes,\nfacilitating verb chaining (see [Examples](#module-examples)).","ref":"TwiML.html#virtual_agent/3"},{"type":"type","title":"TwiML.content/0","doc":"Content which can be used within a TwiML verb. Refer to the `XmlBuilder`\ndocumentation for more information.","ref":"TwiML.html#t:content/0"},{"type":"type","title":"TwiML.t/0","doc":"A TwiML document contains one or more TwiML verbs. These verbs can have\nattributes and can wrap nested TwiML verbs.","ref":"TwiML.html#t:t/0"}],"content_type":"text/markdown"}